==> nonebot_plugin_emojilike-0.0.3.tar.gz: nonebot_plugin_emojilike-0.0.3/README.md <==
<div align="center">
    <a href="https://v2.nonebot.dev/store">
    <img src="./.docs/NoneBotPlugin.svg" width="300" alt="logo"></a>
</div>

<div align="center">

# nonebot-plugin-emojilike

_✨ NoneBot onebotV11 点赞，表情回应插件 ✨_


<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/fllesser/nonebot-plugin-emojilike.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-emojilike">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-emojilike.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">

</div>


> [!NOTE]
> 模板库中自带了一个发布工作流, 你可以使用此工作流自动发布你的插件到 pypi


## 📖 介绍

onebotV11 点赞，表情回应插件

## 💿 安装

<details open>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-emojilike --upgrade

</details>

<details>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<details>
<summary>pip</summary>

    pip install --upgrade nonebot-plugin-emojilike
</details>
<details>
<summary>pdm</summary>

    pdm add nonebot-plugin-emojilike
</details>
<details>
<summary>poetry</summary>

    poetry add nonebot-plugin-emojilike
</details>
<details>
<summary>conda</summary>

    conda install nonebot-plugin-emojilike
</details>

打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot_plugin_template"]

</details>

## ⚙️ 配置

在 nonebot2 项目的`.env`文件中添加下表中的必填配置

| 配置项 | 必填 | 默认值 | 说明 |
|:-----:|:----:|:----:|:----:|
| 配置项1 | 是 | 无 | 配置说明 |
| 配置项2 | 否 | 无 | 配置说明 |

## 🎉 使用
### 指令表
| 指令 | 权限 | 需要@ | 范围 | 说明 |
|:-----:|:----:|:----:|:----:|:----:|
| 指令1 | 主人 | 否 | 私聊 | 指令说明 |
| 指令2 | 群员 | 是 | 群聊 | 指令说明 |
### 效果图
如果有效果图的话

==> nonebot_plugin_emojilike-0.1.0.tar.gz: nonebot_plugin_emojilike-0.1.0/README.md <==
<div align="center">
    <a href="https://v2.nonebot.dev/store">
    <img src="./.docs/NoneBotPlugin.svg" width="300" alt="logo"></a>
</div>

<div align="center">

# nonebot-plugin-emojilike

_✨ NoneBot onebotV11 点赞，表情回应插件 ✨_


<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/fllesser/nonebot-plugin-emojilike.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-emojilike">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-emojilike.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">

</div>


## 📖 介绍

NoneBot onebotV11 点赞，表情回应插件

## 💿 安装

<details open>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-emojilike --upgrade

</details>

<details>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<details>
<summary>pip</summary>

    pip install --upgrade nonebot-plugin-emojilike
</details>
<details>
<summary>pdm</summary>

    pdm add nonebot-plugin-emojilike
</details>
<details>
<summary>poetry</summary>

    poetry add nonebot-plugin-emojilike
</details>
<details>
<summary>conda</summary>

    conda install nonebot-plugin-emojilike
</details>

打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot_plugin_emojilike"]

</details>


## 🎉 使用
### 指令表
| 指令 | 权限 | 需要@ | 范围 | 说明 |
|:-----:|:----:|:----:|:----:|:----:|
| 赞我 | 群员 | 否 | 群聊 | 顾名思义 |
| 天天赞我 | 群员 | 否 | 群聊 | 顾名思义 |

## 效果图
<img src=".docs/1.png">
<img src=".docs/2.png">
<img src=".docs/3.png">
